@@ -24,6 +24,33 @@ import urllib
 
 NEXUS_ROOT = os.path.normpath(os.path.dirname(__file__))
 
+
+try:
+    from django.views.decorators.csrf import ensure_csrf_cookie
+except ImportError:  # must be < Django 1.3
+    from django.views.decorators.csrf import CsrfViewMiddleware
+    from django.middleware.csrf import get_token
+    from django.utils.decorators import decorator_from_middleware
+
+    class _EnsureCsrfCookie(CsrfViewMiddleware):
+        def _reject(self, request, reason):
+            return None
+
+        def process_view(self, request, callback, callback_args, callback_kwargs):
+            retval = super(_EnsureCsrfCookie, self).process_view(request, callback, callback_args, callback_kwargs)
+            # Forces process_response to send the cookie
+            get_token(request)
+            return retval
+
+
+    ensure_csrf_cookie = decorator_from_middleware(_EnsureCsrfCookie)
+    ensure_csrf_cookie.__name__ = 'ensure_csrf_cookie'
+    ensure_csrf_cookie.__doc__ = """
+    Use this decorator to ensure that a view sets a CSRF cookie, whether or not it
+    uses the csrf_token template tag, or the CsrfViewMiddleware is used.
+    """
+
+
 class NexusSite(object):
     def __init__(self, name=None, app_name='nexus'):
         self._registry = {}
@@ -48,7 +75,7 @@ class NexusSite(object):
             module.app_name = module.name = namespace
         self._registry[namespace] = (module, category)
         return module
-    
+
     def unregister(self, namespace):
         if namespace in self._registry:
             del self._registry[namespace]
@@ -63,7 +90,7 @@ class NexusSite(object):
             url(r'^login/$', self.login, name='login'),
             url(r'^logout/$', self.as_view(self.logout), name='logout'),
         ), self.app_name, self.name
-        
+
         urlpatterns = patterns('',
             url(r'^', include(base_urls)),
         )
@@ -71,8 +98,9 @@ class NexusSite(object):
             urlpatterns += patterns('',
                 url(r'^%s/' % namespace, include(module.urls)),
             )
-        
+
         return urlpatterns
+
     def urls(self):
         return self.get_urls()
 
@@ -109,6 +137,8 @@ class NexusSite(object):
         if not getattr(view, 'csrf_exempt', False):
             inner = csrf_protect(inner)
 
+        inner = ensure_csrf_cookie(inner)
+
         return update_wrapper(inner, view)
 
     def get_context(self, request):
@@ -123,7 +153,7 @@ class NexusSite(object):
     def get_modules(self):
         for k, v in self._registry.iteritems():
             yield k, v[0]
-    
+
     def get_module(self, module):
         return self._registry[module][0]
 
@@ -139,14 +169,14 @@ class NexusSite(object):
             current_app = self.name
         else:
             current_app = '%s:%s' % (self.name, current_app)
-        
+
         if request:
             context_instance = RequestContext(request, current_app=current_app)
         else:
             context_instance = None
 
         context.update(self.get_context(request))
-        
+
         return render_to_string(template, context,
             context_instance=context_instance
         )
@@ -157,20 +187,20 @@ class NexusSite(object):
             current_app = self.name
         else:
             current_app = '%s:%s' % (self.name, current_app)
-        
+
         if request:
             context_instance = RequestContext(request, current_app=current_app)
         else:
             context_instance = None
 
         context.update(self.get_context(request))
-        
+
         return render_to_response(template, context,
             context_instance=context_instance
         )
 
     ## Our views
-    
+
     def media(self, request, module, path):
         """
         Serve static files below a given point in the directory structure.
@@ -179,7 +209,7 @@ class NexusSite(object):
             document_root = os.path.join(NEXUS_ROOT, 'media')
         else:
             document_root = self.get_module(module).media_root
-        
+
         path = posixpath.normpath(urllib.unquote(path))
         path = path.lstrip('/')
         newpath = ''
@@ -210,7 +240,7 @@ class NexusSite(object):
         response = HttpResponse(contents, mimetype=mimetype)
         response["Last-Modified"] = http_date(statobj[stat.ST_MTIME])
         response["Content-Length"] = len(contents)
-        return response        
+        return response
 
     def login(self, request):
         "Login form"
@@ -233,7 +263,7 @@ class NexusSite(object):
             'form': form,
         }, request)
     login = never_cache(login)
-    
+
     def logout(self, request):
         "Logs out user and redirects them to Nexus home"
         from django.contrib.auth import logout
@@ -253,7 +283,7 @@ class NexusSite(object):
                 # Show by default, unless a permission is required
                 if not module.permission or request.user.has_perm(module.permission):
                     module_set.append((module.get_dashboard_title(), module.render_on_dashboard(request), home_url))
-        
+
         return self.render_to_response('nexus/dashboard.html', {
             'module_set': module_set,
         }, request)
